# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/authz/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos.base.abci.v1beta1 import abci_pb2 as cosmos_dot_base_dot_abci_dot_v1beta1_dot_abci__pb2
from cosmos.authz.v1beta1 import authz_pb2 as cosmos_dot_authz_dot_v1beta1_dot_authz__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x63osmos/authz/v1beta1/tx.proto\x12\x14\x63osmos.authz.v1beta1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a#cosmos/base/abci/v1beta1/abci.proto\x1a cosmos/authz/v1beta1/authz.proto\"^\n\x08MsgGrant\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x30\n\x05grant\x18\x03 \x01(\x0b\x32\x1b.cosmos.authz.v1beta1.GrantB\x04\xc8\xde\x1f\x00\"\"\n\x0fMsgExecResponse\x12\x0f\n\x07results\x18\x01 \x03(\x0c\"`\n\x07MsgExec\x12\x0f\n\x07grantee\x18\x01 \x01(\t\x12\x44\n\x04msgs\x18\x02 \x03(\x0b\x32\x14.google.protobuf.AnyB \xca\xb4-\x1csdk.Msg, authz.Authorization\"\x12\n\x10MsgGrantResponse\"C\n\tMsgRevoke\x12\x0f\n\x07granter\x18\x01 \x01(\t\x12\x0f\n\x07grantee\x18\x02 \x01(\t\x12\x14\n\x0cmsg_type_url\x18\x03 \x01(\t\"\x13\n\x11MsgRevokeResponse2\xf8\x01\n\x03Msg\x12O\n\x05Grant\x12\x1e.cosmos.authz.v1beta1.MsgGrant\x1a&.cosmos.authz.v1beta1.MsgGrantResponse\x12L\n\x04\x45xec\x12\x1d.cosmos.authz.v1beta1.MsgExec\x1a%.cosmos.authz.v1beta1.MsgExecResponse\x12R\n\x06Revoke\x12\x1f.cosmos.authz.v1beta1.MsgRevoke\x1a\'.cosmos.authz.v1beta1.MsgRevokeResponseB*Z$github.com/cosmos/cosmos-sdk/x/authz\xc8\xe1\x1e\x00\x62\x06proto3')



_MSGGRANT = DESCRIPTOR.message_types_by_name['MsgGrant']
_MSGEXECRESPONSE = DESCRIPTOR.message_types_by_name['MsgExecResponse']
_MSGEXEC = DESCRIPTOR.message_types_by_name['MsgExec']
_MSGGRANTRESPONSE = DESCRIPTOR.message_types_by_name['MsgGrantResponse']
_MSGREVOKE = DESCRIPTOR.message_types_by_name['MsgRevoke']
_MSGREVOKERESPONSE = DESCRIPTOR.message_types_by_name['MsgRevokeResponse']
MsgGrant = _reflection.GeneratedProtocolMessageType('MsgGrant', (_message.Message,), {
  'DESCRIPTOR' : _MSGGRANT,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgGrant)
  })
_sym_db.RegisterMessage(MsgGrant)

MsgExecResponse = _reflection.GeneratedProtocolMessageType('MsgExecResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGEXECRESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgExecResponse)
  })
_sym_db.RegisterMessage(MsgExecResponse)

MsgExec = _reflection.GeneratedProtocolMessageType('MsgExec', (_message.Message,), {
  'DESCRIPTOR' : _MSGEXEC,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgExec)
  })
_sym_db.RegisterMessage(MsgExec)

MsgGrantResponse = _reflection.GeneratedProtocolMessageType('MsgGrantResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGGRANTRESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgGrantResponse)
  })
_sym_db.RegisterMessage(MsgGrantResponse)

MsgRevoke = _reflection.GeneratedProtocolMessageType('MsgRevoke', (_message.Message,), {
  'DESCRIPTOR' : _MSGREVOKE,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgRevoke)
  })
_sym_db.RegisterMessage(MsgRevoke)

MsgRevokeResponse = _reflection.GeneratedProtocolMessageType('MsgRevokeResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREVOKERESPONSE,
  '__module__' : 'cosmos.authz.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.authz.v1beta1.MsgRevokeResponse)
  })
_sym_db.RegisterMessage(MsgRevokeResponse)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/authz\310\341\036\000'
  _MSGGRANT.fields_by_name['grant']._options = None
  _MSGGRANT.fields_by_name['grant']._serialized_options = b'\310\336\037\000'
  _MSGEXEC.fields_by_name['msgs']._options = None
  _MSGEXEC.fields_by_name['msgs']._serialized_options = b'\312\264-\034sdk.Msg, authz.Authorization'
  _MSGGRANT._serialized_start=235
  _MSGGRANT._serialized_end=329
  _MSGEXECRESPONSE._serialized_start=331
  _MSGEXECRESPONSE._serialized_end=365
  _MSGEXEC._serialized_start=367
  _MSGEXEC._serialized_end=463
  _MSGGRANTRESPONSE._serialized_start=465
  _MSGGRANTRESPONSE._serialized_end=483
  _MSGREVOKE._serialized_start=485
  _MSGREVOKE._serialized_end=552
  _MSGREVOKERESPONSE._serialized_start=554
  _MSGREVOKERESPONSE._serialized_end=573
  _MSG._serialized_start=576
  _MSG._serialized_end=824
# @@protoc_insertion_point(module_scope)



from typing import List

from nibiru.client import Client
from nibiru.common import TxConfig
from nibiru.composer import Composer
from nibiru.network import Network
from nibiru.proto.cosmos.base.v1beta1.coin_pb2 import Coin
from nibiru.wallet import PrivateKey

from .common import Tx
from .dex import Dex
from .perp import Perp


class TxClient(Tx):
    def __init__(self, client: Client, network: Network, priv_key: PrivateKey, config: TxConfig):
        super().__init__(client=client, network=network, priv_key=priv_key, config=config)
        self.dex = Dex(client=client, network=network, priv_key=priv_key, config=config)
        self.perp = Perp(client=client, network=network, priv_key=priv_key, config=config)

    def msg_send(self, from_address: str, to_address: str, coins: List[Coin], **kwargs):
        msg = Composer.msg_send(from_address, to_address, coins=coins)
        return super().execute_msg(msg, **kwargs)

    def msg_exec(self, grantee: str, msgs: List, **kwargs):
        msg = Composer.msg_exec(grantee, msgs)
        return super().execute_msg(msg, **kwargs)

    def msg_revoke(self, granter: str, grantee: str, msg_type: str, **kwargs):
        msg = Composer.msg_revoke(granter, grantee, msg_type)
        return super().execute_msg(msg, **kwargs)

    def msg_delegate(self, delegator_address: str, validator_address: str, amount: float, **kwargs):
        msg = Composer.msg_delegate(delegator_address, validator_address, amount)
        return super().execute_msg(msg, **kwargs)

    def msg_withdraw_delegator_reward(self, delegator_address: str, validator_address: str, **kwargs):
        msg = Composer.msg_withdraw_delegator_reward(delegator_address, validator_address)
        return super().execute_msg(msg, **kwargs)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from stablecoin import tx_pb2 as stablecoin_dot_tx__pb2


class MsgStub(object):
    """Msg defines the x/stablecoin Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MintStable = channel.unary_unary(
                '/nibiru.stablecoin.v1.Msg/MintStable',
                request_serializer=stablecoin_dot_tx__pb2.MsgMintStable.SerializeToString,
                response_deserializer=stablecoin_dot_tx__pb2.MsgMintStableResponse.FromString,
                )
        self.BurnStable = channel.unary_unary(
                '/nibiru.stablecoin.v1.Msg/BurnStable',
                request_serializer=stablecoin_dot_tx__pb2.MsgBurnStable.SerializeToString,
                response_deserializer=stablecoin_dot_tx__pb2.MsgBurnStableResponse.FromString,
                )
        self.Recollateralize = channel.unary_unary(
                '/nibiru.stablecoin.v1.Msg/Recollateralize',
                request_serializer=stablecoin_dot_tx__pb2.MsgRecollateralize.SerializeToString,
                response_deserializer=stablecoin_dot_tx__pb2.MsgRecollateralizeResponse.FromString,
                )
        self.Buyback = channel.unary_unary(
                '/nibiru.stablecoin.v1.Msg/Buyback',
                request_serializer=stablecoin_dot_tx__pb2.MsgBuyback.SerializeToString,
                response_deserializer=stablecoin_dot_tx__pb2.MsgBuybackResponse.FromString,
                )


class MsgServicer(object):
    """Msg defines the x/stablecoin Msg service.
    """

    def MintStable(self, request, context):
        """MintStable defines a method for trading a mixture of GOV and COLL to mint an 
        equivalent value of stablecoins. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BurnStable(self, request, context):
        """BurnStable defines a method for redeeming/burning stablecoins to receive an 
        equivalent value as a mixture of governance and collateral tokens. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Recollateralize(self, request, context):
        """Recollateralize defines a method for manually adding collateral to the 
        protocol in exchange for an equivalent stablecoin value in governance tokens 
        plus a small bonus. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Buyback(self, request, context):
        """Buyback defines a method for manually adding NIBI to the protocol 
        in exchange for an equivalent stablecoin value in collateral, effectively 
        executing a share buyback for Nibiru Chain. The NIBI purchased by the protocol 
        is then burned, distributing value to all NIBI hodlers. 
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MintStable': grpc.unary_unary_rpc_method_handler(
                    servicer.MintStable,
                    request_deserializer=stablecoin_dot_tx__pb2.MsgMintStable.FromString,
                    response_serializer=stablecoin_dot_tx__pb2.MsgMintStableResponse.SerializeToString,
            ),
            'BurnStable': grpc.unary_unary_rpc_method_handler(
                    servicer.BurnStable,
                    request_deserializer=stablecoin_dot_tx__pb2.MsgBurnStable.FromString,
                    response_serializer=stablecoin_dot_tx__pb2.MsgBurnStableResponse.SerializeToString,
            ),
            'Recollateralize': grpc.unary_unary_rpc_method_handler(
                    servicer.Recollateralize,
                    request_deserializer=stablecoin_dot_tx__pb2.MsgRecollateralize.FromString,
                    response_serializer=stablecoin_dot_tx__pb2.MsgRecollateralizeResponse.SerializeToString,
            ),
            'Buyback': grpc.unary_unary_rpc_method_handler(
                    servicer.Buyback,
                    request_deserializer=stablecoin_dot_tx__pb2.MsgBuyback.FromString,
                    response_serializer=stablecoin_dot_tx__pb2.MsgBuybackResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.stablecoin.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the x/stablecoin Msg service.
    """

    @staticmethod
    def MintStable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Msg/MintStable',
            stablecoin_dot_tx__pb2.MsgMintStable.SerializeToString,
            stablecoin_dot_tx__pb2.MsgMintStableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BurnStable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Msg/BurnStable',
            stablecoin_dot_tx__pb2.MsgBurnStable.SerializeToString,
            stablecoin_dot_tx__pb2.MsgBurnStableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Recollateralize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Msg/Recollateralize',
            stablecoin_dot_tx__pb2.MsgRecollateralize.SerializeToString,
            stablecoin_dot_tx__pb2.MsgRecollateralizeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Buyback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.stablecoin.v1.Msg/Buyback',
            stablecoin_dot_tx__pb2.MsgBuyback.SerializeToString,
            stablecoin_dot_tx__pb2.MsgBuybackResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: perp/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from perp.v1 import state_pb2 as perp_dot_v1_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13perp/v1/query.proto\x12\x0enibiru.perp.v1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x13perp/v1/state.proto\"\x14\n\x12QueryParamsRequest\"C\n\x13QueryParamsResponse\x12,\n\x06params\x18\x01 \x01(\x0b\x32\x16.nibiru.perp.v1.ParamsB\x04\xc8\xde\x1f\x00\"@\n\x1aQueryTraderPositionRequest\x12\x12\n\ntoken_pair\x18\x01 \x01(\t\x12\x0e\n\x06trader\x18\x02 \x01(\t\"\xa2\x02\n\x1bQueryTraderPositionResponse\x12*\n\x08position\x18\x01 \x01(\x0b\x32\x18.nibiru.perp.v1.Position\x12I\n\x11position_notional\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0eunrealized_pnl\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0cmargin_ratio\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x32\x89\x02\n\x05Query\x12n\n\x06Params\x12\".nibiru.perp.v1.QueryParamsRequest\x1a#.nibiru.perp.v1.QueryParamsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/nibiru/perp/params\x12\x8f\x01\n\x0eTraderPosition\x12*.nibiru.perp.v1.QueryTraderPositionRequest\x1a+.nibiru.perp.v1.QueryTraderPositionResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/nibiru/perp/trader_positionB,Z*github.com/NibiruChain/nibiru/x/perp/typesb\x06proto3')



_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
_QUERYTRADERPOSITIONREQUEST = DESCRIPTOR.message_types_by_name['QueryTraderPositionRequest']
_QUERYTRADERPOSITIONRESPONSE = DESCRIPTOR.message_types_by_name['QueryTraderPositionResponse']
QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'perp.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'perp.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryTraderPositionRequest = _reflection.GeneratedProtocolMessageType('QueryTraderPositionRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERPOSITIONREQUEST,
  '__module__' : 'perp.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.QueryTraderPositionRequest)
  })
_sym_db.RegisterMessage(QueryTraderPositionRequest)

QueryTraderPositionResponse = _reflection.GeneratedProtocolMessageType('QueryTraderPositionResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERPOSITIONRESPONSE,
  '__module__' : 'perp.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.perp.v1.QueryTraderPositionResponse)
  })
_sym_db.RegisterMessage(QueryTraderPositionResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z*github.com/NibiruChain/nibiru/x/perp/types'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERYTRADERPOSITIONRESPONSE.fields_by_name['position_notional']._options = None
  _QUERYTRADERPOSITIONRESPONSE.fields_by_name['position_notional']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYTRADERPOSITIONRESPONSE.fields_by_name['unrealized_pnl']._options = None
  _QUERYTRADERPOSITIONRESPONSE.fields_by_name['unrealized_pnl']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYTRADERPOSITIONRESPONSE.fields_by_name['margin_ratio']._options = None
  _QUERYTRADERPOSITIONRESPONSE.fields_by_name['margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\025\022\023/nibiru/perp/params'
  _QUERY.methods_by_name['TraderPosition']._options = None
  _QUERY.methods_by_name['TraderPosition']._serialized_options = b'\202\323\344\223\002\036\022\034/nibiru/perp/trader_position'
  _QUERYPARAMSREQUEST._serialized_start=112
  _QUERYPARAMSREQUEST._serialized_end=132
  _QUERYPARAMSRESPONSE._serialized_start=134
  _QUERYPARAMSRESPONSE._serialized_end=201
  _QUERYTRADERPOSITIONREQUEST._serialized_start=203
  _QUERYTRADERPOSITIONREQUEST._serialized_end=267
  _QUERYTRADERPOSITIONRESPONSE._serialized_start=270
  _QUERYTRADERPOSITIONRESPONSE._serialized_end=560
  _QUERY._serialized_start=563
  _QUERY._serialized_end=828
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lockup/v1/lock.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14lockup/v1/lock.proto\x12\x10nibiru.lockup.v1\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xbf\x02\n\x04Lock\x12\x0f\n\x07lock_id\x18\x01 \x01(\x04\x12\x1f\n\x05owner\x18\x02 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"owner\"\x12^\n\x08\x64uration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB1\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xea\xde\x1f\x12\x64uration,omitempty\xf2\xde\x1f\x0fyaml:\"duration\"\x12I\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x1b\x90\xdf\x1f\x01\xc8\xde\x1f\x00\xf2\xde\x1f\x0fyaml:\"end_time\"\x12Z\n\x05\x63oins\x18\x05 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsB.Z,github.com/NibiruChain/nibiru/x/lockup/typesb\x06proto3'
)


_LOCK = DESCRIPTOR.message_types_by_name['Lock']
Lock = _reflection.GeneratedProtocolMessageType(
    'Lock',
    (_message.Message,),
    {
        'DESCRIPTOR': _LOCK,
        '__module__': 'lockup.v1.lock_pb2'
        # @@protoc_insertion_point(class_scope:nibiru.lockup.v1.Lock)
    },
)
_sym_db.RegisterMessage(Lock)

if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/lockup/types'
    _LOCK.fields_by_name['owner']._options = None
    _LOCK.fields_by_name['owner']._serialized_options = b'\362\336\037\014yaml:\"owner\"'
    _LOCK.fields_by_name['duration']._options = None
    _LOCK.fields_by_name[
        'duration'
    ]._serialized_options = (
        b'\310\336\037\000\230\337\037\001\352\336\037\022duration,omitempty\362\336\037\017yaml:\"duration\"'
    )
    _LOCK.fields_by_name['end_time']._options = None
    _LOCK.fields_by_name[
        'end_time'
    ]._serialized_options = b'\220\337\037\001\310\336\037\000\362\336\037\017yaml:\"end_time\"'
    _LOCK.fields_by_name['coins']._options = None
    _LOCK.fields_by_name[
        'coins'
    ]._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
    _LOCK._serialized_start = 162
    _LOCK._serialized_end = 481
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/distribution/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$cosmos/distribution/v1beta1/tx.proto\x12\x1b\x63osmos.distribution.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x91\x01\n\x15MsgSetWithdrawAddress\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x35\n\x10withdraw_address\x18\x02 \x01(\tB\x1b\xf2\xde\x1f\x17yaml:\"withdraw_address\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgSetWithdrawAddressResponse\"\x98\x01\n\x1aMsgWithdrawDelegatorReward\x12\x37\n\x11\x64\x65legator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"delegator_address\"\x12\x37\n\x11validator_address\x18\x02 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"$\n\"MsgWithdrawDelegatorRewardResponse\"c\n\x1eMsgWithdrawValidatorCommission\x12\x37\n\x11validator_address\x18\x01 \x01(\tB\x1c\xf2\xde\x1f\x18yaml:\"validator_address\":\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"(\n&MsgWithdrawValidatorCommissionResponse\"\x90\x01\n\x14MsgFundCommunityPool\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tdepositor\x18\x02 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgFundCommunityPoolResponse2\xc8\x04\n\x03Msg\x12\x84\x01\n\x12SetWithdrawAddress\x12\x32.cosmos.distribution.v1beta1.MsgSetWithdrawAddress\x1a:.cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse\x12\x93\x01\n\x17WithdrawDelegatorReward\x12\x37.cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward\x1a?.cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse\x12\x9f\x01\n\x1bWithdrawValidatorCommission\x12;.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission\x1a\x43.cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse\x12\x81\x01\n\x11\x46undCommunityPool\x12\x31.cosmos.distribution.v1beta1.MsgFundCommunityPool\x1a\x39.cosmos.distribution.v1beta1.MsgFundCommunityPoolResponseB7Z1github.com/cosmos/cosmos-sdk/x/distribution/types\xa8\xe2\x1e\x01\x62\x06proto3')



_MSGSETWITHDRAWADDRESS = DESCRIPTOR.message_types_by_name['MsgSetWithdrawAddress']
_MSGSETWITHDRAWADDRESSRESPONSE = DESCRIPTOR.message_types_by_name['MsgSetWithdrawAddressResponse']
_MSGWITHDRAWDELEGATORREWARD = DESCRIPTOR.message_types_by_name['MsgWithdrawDelegatorReward']
_MSGWITHDRAWDELEGATORREWARDRESPONSE = DESCRIPTOR.message_types_by_name['MsgWithdrawDelegatorRewardResponse']
_MSGWITHDRAWVALIDATORCOMMISSION = DESCRIPTOR.message_types_by_name['MsgWithdrawValidatorCommission']
_MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE = DESCRIPTOR.message_types_by_name['MsgWithdrawValidatorCommissionResponse']
_MSGFUNDCOMMUNITYPOOL = DESCRIPTOR.message_types_by_name['MsgFundCommunityPool']
_MSGFUNDCOMMUNITYPOOLRESPONSE = DESCRIPTOR.message_types_by_name['MsgFundCommunityPoolResponse']
MsgSetWithdrawAddress = _reflection.GeneratedProtocolMessageType('MsgSetWithdrawAddress', (_message.Message,), {
  'DESCRIPTOR' : _MSGSETWITHDRAWADDRESS,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgSetWithdrawAddress)
  })
_sym_db.RegisterMessage(MsgSetWithdrawAddress)

MsgSetWithdrawAddressResponse = _reflection.GeneratedProtocolMessageType('MsgSetWithdrawAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGSETWITHDRAWADDRESSRESPONSE,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgSetWithdrawAddressResponse)
  })
_sym_db.RegisterMessage(MsgSetWithdrawAddressResponse)

MsgWithdrawDelegatorReward = _reflection.GeneratedProtocolMessageType('MsgWithdrawDelegatorReward', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWDELEGATORREWARD,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgWithdrawDelegatorReward)
  })
_sym_db.RegisterMessage(MsgWithdrawDelegatorReward)

MsgWithdrawDelegatorRewardResponse = _reflection.GeneratedProtocolMessageType('MsgWithdrawDelegatorRewardResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWDELEGATORREWARDRESPONSE,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgWithdrawDelegatorRewardResponse)
  })
_sym_db.RegisterMessage(MsgWithdrawDelegatorRewardResponse)

MsgWithdrawValidatorCommission = _reflection.GeneratedProtocolMessageType('MsgWithdrawValidatorCommission', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWVALIDATORCOMMISSION,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgWithdrawValidatorCommission)
  })
_sym_db.RegisterMessage(MsgWithdrawValidatorCommission)

MsgWithdrawValidatorCommissionResponse = _reflection.GeneratedProtocolMessageType('MsgWithdrawValidatorCommissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgWithdrawValidatorCommissionResponse)
  })
_sym_db.RegisterMessage(MsgWithdrawValidatorCommissionResponse)

MsgFundCommunityPool = _reflection.GeneratedProtocolMessageType('MsgFundCommunityPool', (_message.Message,), {
  'DESCRIPTOR' : _MSGFUNDCOMMUNITYPOOL,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgFundCommunityPool)
  })
_sym_db.RegisterMessage(MsgFundCommunityPool)

MsgFundCommunityPoolResponse = _reflection.GeneratedProtocolMessageType('MsgFundCommunityPoolResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGFUNDCOMMUNITYPOOLRESPONSE,
  '__module__' : 'cosmos.distribution.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.distribution.v1beta1.MsgFundCommunityPoolResponse)
  })
_sym_db.RegisterMessage(MsgFundCommunityPoolResponse)

_MSG = DESCRIPTOR.services_by_name['Msg']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/cosmos/cosmos-sdk/x/distribution/types\250\342\036\001'
  _MSGSETWITHDRAWADDRESS.fields_by_name['delegator_address']._options = None
  _MSGSETWITHDRAWADDRESS.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _MSGSETWITHDRAWADDRESS.fields_by_name['withdraw_address']._options = None
  _MSGSETWITHDRAWADDRESS.fields_by_name['withdraw_address']._serialized_options = b'\362\336\037\027yaml:\"withdraw_address\"'
  _MSGSETWITHDRAWADDRESS._options = None
  _MSGSETWITHDRAWADDRESS._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGWITHDRAWDELEGATORREWARD.fields_by_name['delegator_address']._options = None
  _MSGWITHDRAWDELEGATORREWARD.fields_by_name['delegator_address']._serialized_options = b'\362\336\037\030yaml:\"delegator_address\"'
  _MSGWITHDRAWDELEGATORREWARD.fields_by_name['validator_address']._options = None
  _MSGWITHDRAWDELEGATORREWARD.fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _MSGWITHDRAWDELEGATORREWARD._options = None
  _MSGWITHDRAWDELEGATORREWARD._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGWITHDRAWVALIDATORCOMMISSION.fields_by_name['validator_address']._options = None
  _MSGWITHDRAWVALIDATORCOMMISSION.fields_by_name['validator_address']._serialized_options = b'\362\336\037\030yaml:\"validator_address\"'
  _MSGWITHDRAWVALIDATORCOMMISSION._options = None
  _MSGWITHDRAWVALIDATORCOMMISSION._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGFUNDCOMMUNITYPOOL.fields_by_name['amount']._options = None
  _MSGFUNDCOMMUNITYPOOL.fields_by_name['amount']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGFUNDCOMMUNITYPOOL._options = None
  _MSGFUNDCOMMUNITYPOOL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGSETWITHDRAWADDRESS._serialized_start=124
  _MSGSETWITHDRAWADDRESS._serialized_end=269
  _MSGSETWITHDRAWADDRESSRESPONSE._serialized_start=271
  _MSGSETWITHDRAWADDRESSRESPONSE._serialized_end=302
  _MSGWITHDRAWDELEGATORREWARD._serialized_start=305
  _MSGWITHDRAWDELEGATORREWARD._serialized_end=457
  _MSGWITHDRAWDELEGATORREWARDRESPONSE._serialized_start=459
  _MSGWITHDRAWDELEGATORREWARDRESPONSE._serialized_end=495
  _MSGWITHDRAWVALIDATORCOMMISSION._serialized_start=497
  _MSGWITHDRAWVALIDATORCOMMISSION._serialized_end=596
  _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE._serialized_start=598
  _MSGWITHDRAWVALIDATORCOMMISSIONRESPONSE._serialized_end=638
  _MSGFUNDCOMMUNITYPOOL._serialized_start=641
  _MSGFUNDCOMMUNITYPOOL._serialized_end=785
  _MSGFUNDCOMMUNITYPOOLRESPONSE._serialized_start=787
  _MSGFUNDCOMMUNITYPOOLRESPONSE._serialized_end=817
  _MSG._serialized_start=820
  _MSG._serialized_end=1404
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/v1beta1/coin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/base/v1beta1/coin.proto\x12\x13\x63osmos.base.v1beta1\x1a\x14gogoproto/gogo.proto\"8\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1b\n\x06\x61mount\x18\x02 \x01(\tB\x0b\xda\xde\x1f\x03Int\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\";\n\x07\x44\x65\x63\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1b\n\x06\x61mount\x18\x02 \x01(\tB\x0b\xda\xde\x1f\x03\x44\x65\x63\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"$\n\x08IntProto\x12\x18\n\x03int\x18\x01 \x01(\tB\x0b\xda\xde\x1f\x03Int\xc8\xde\x1f\x00\"$\n\x08\x44\x65\x63Proto\x12\x18\n\x03\x64\x65\x63\x18\x01 \x01(\tB\x0b\xda\xde\x1f\x03\x44\x65\x63\xc8\xde\x1f\x00\x42,Z\"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\x62\x06proto3')



_COIN = DESCRIPTOR.message_types_by_name['Coin']
_DECCOIN = DESCRIPTOR.message_types_by_name['DecCoin']
_INTPROTO = DESCRIPTOR.message_types_by_name['IntProto']
_DECPROTO = DESCRIPTOR.message_types_by_name['DecProto']
Coin = _reflection.GeneratedProtocolMessageType('Coin', (_message.Message,), {
  'DESCRIPTOR' : _COIN,
  '__module__' : 'cosmos.base.v1beta1.coin_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.v1beta1.Coin)
  })
_sym_db.RegisterMessage(Coin)

DecCoin = _reflection.GeneratedProtocolMessageType('DecCoin', (_message.Message,), {
  'DESCRIPTOR' : _DECCOIN,
  '__module__' : 'cosmos.base.v1beta1.coin_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.v1beta1.DecCoin)
  })
_sym_db.RegisterMessage(DecCoin)

IntProto = _reflection.GeneratedProtocolMessageType('IntProto', (_message.Message,), {
  'DESCRIPTOR' : _INTPROTO,
  '__module__' : 'cosmos.base.v1beta1.coin_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.v1beta1.IntProto)
  })
_sym_db.RegisterMessage(IntProto)

DecProto = _reflection.GeneratedProtocolMessageType('DecProto', (_message.Message,), {
  'DESCRIPTOR' : _DECPROTO,
  '__module__' : 'cosmos.base.v1beta1.coin_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.v1beta1.DecProto)
  })
_sym_db.RegisterMessage(DecProto)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\"github.com/cosmos/cosmos-sdk/types\330\341\036\000\200\342\036\000'
  _COIN.fields_by_name['amount']._options = None
  _COIN.fields_by_name['amount']._serialized_options = b'\332\336\037\003Int\310\336\037\000'
  _COIN._options = None
  _COIN._serialized_options = b'\350\240\037\001'
  _DECCOIN.fields_by_name['amount']._options = None
  _DECCOIN.fields_by_name['amount']._serialized_options = b'\332\336\037\003Dec\310\336\037\000'
  _DECCOIN._options = None
  _DECCOIN._serialized_options = b'\350\240\037\001'
  _INTPROTO.fields_by_name['int']._options = None
  _INTPROTO.fields_by_name['int']._serialized_options = b'\332\336\037\003Int\310\336\037\000'
  _DECPROTO.fields_by_name['dec']._options = None
  _DECPROTO.fields_by_name['dec']._serialized_options = b'\332\336\037\003Dec\310\336\037\000'
  _COIN._serialized_start=77
  _COIN._serialized_end=133
  _DECCOIN._serialized_start=135
  _DECCOIN._serialized_end=194
  _INTPROTO._serialized_start=196
  _INTPROTO._serialized_end=232
  _DECPROTO._serialized_start=234
  _DECPROTO._serialized_end=270
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from cosmos.bank.v1beta1 import query_pb2 as cosmos_dot_bank_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Balance = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/Balance',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.FromString,
                )
        self.AllBalances = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/AllBalances',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.FromString,
                )
        self.SpendableBalances = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/SpendableBalances',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.FromString,
                )
        self.TotalSupply = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/TotalSupply',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.FromString,
                )
        self.SupplyOf = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/SupplyOf',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.FromString,
                )
        self.Params = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/Params',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                )
        self.DenomMetadata = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/DenomMetadata',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.FromString,
                )
        self.DenomsMetadata = channel.unary_unary(
                '/cosmos.bank.v1beta1.Query/DenomsMetadata',
                request_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.SerializeToString,
                response_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Balance(self, request, context):
        """Balance queries the balance of a single coin for a single account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllBalances(self, request, context):
        """AllBalances queries the balance of all coins for a single account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SpendableBalances(self, request, context):
        """SpendableBalances queries the spenable balance of all coins for a single
        account.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TotalSupply(self, request, context):
        """TotalSupply queries the total supply of all coins.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SupplyOf(self, request, context):
        """SupplyOf queries the supply of a single coin.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Params(self, request, context):
        """Params queries the parameters of x/bank module.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomMetadata(self, request, context):
        """DenomsMetadata queries the client metadata of a given coin denomination.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DenomsMetadata(self, request, context):
        """DenomsMetadata queries the client metadata for all registered coin denominations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Balance': grpc.unary_unary_rpc_method_handler(
                    servicer.Balance,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.SerializeToString,
            ),
            'AllBalances': grpc.unary_unary_rpc_method_handler(
                    servicer.AllBalances,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.SerializeToString,
            ),
            'SpendableBalances': grpc.unary_unary_rpc_method_handler(
                    servicer.SpendableBalances,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.SerializeToString,
            ),
            'TotalSupply': grpc.unary_unary_rpc_method_handler(
                    servicer.TotalSupply,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.SerializeToString,
            ),
            'SupplyOf': grpc.unary_unary_rpc_method_handler(
                    servicer.SupplyOf,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.SerializeToString,
            ),
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'DenomMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomMetadata,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.SerializeToString,
            ),
            'DenomsMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.DenomsMetadata,
                    request_deserializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.FromString,
                    response_serializer=cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.bank.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Balance(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/Balance',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryBalanceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AllBalances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/AllBalances',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryAllBalancesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SpendableBalances(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/SpendableBalances',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySpendableBalancesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TotalSupply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/TotalSupply',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryTotalSupplyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SupplyOf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/SupplyOf',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QuerySupplyOfResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/Params',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/DenomMetadata',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomMetadataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DenomsMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/cosmos.bank.v1beta1.Query/DenomsMetadata',
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataRequest.SerializeToString,
            cosmos_dot_bank_dot_v1beta1_dot_query__pb2.QueryDenomsMetadataResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: incentivization/v1/incentivization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(incentivization/v1/incentivization.proto\x12\x19nibiru.incentivization.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xab\x02\n\x1fMsgCreateIncentivizationProgram\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08lp_denom\x18\x02 \x01(\t\x12<\n\x13min_lockup_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\x98\xdf\x1f\x01\x12\x34\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\x90\xdf\x1f\x01\x12\x0e\n\x06\x65pochs\x18\x05 \x01(\x03\x12\x62\n\rinitial_funds\x18\x07 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"=\n\'MsgCreateIncentivizationProgramResponse\x12\x12\n\nprogram_id\x18\x01 \x01(\x04\"\x97\x01\n\x1dMsgFundIncentivizationProgram\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\x12Z\n\x05\x66unds\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\'\n%MsgFundIncentivizationProgramResponse\"\xe4\x01\n\x16IncentivizationProgram\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x16\n\x0e\x65scrow_address\x18\x02 \x01(\t\x12\x18\n\x10remaining_epochs\x18\x03 \x01(\x03\x12\x10\n\x08lp_denom\x18\x04 \x01(\t\x12@\n\x13min_lockup_duration\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\x98\xdf\x1f\x01\xc8\xde\x1f\x00\x12\x38\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\x90\xdf\x1f\x01\xc8\xde\x1f\x00\"c\n\x0cGenesisState\x12S\n\x18incentivization_programs\x18\x01 \x03(\x0b\x32\x31.nibiru.incentivization.v1.IncentivizationProgram\"0\n\"QueryIncentivizationProgramRequest\x12\n\n\x02id\x18\x01 \x01(\x04\"y\n#QueryIncentivizationProgramResponse\x12R\n\x17incentivization_program\x18\x01 \x01(\x0b\x32\x31.nibiru.incentivization.v1.IncentivizationProgram\"a\n#QueryIncentivizationProgramsRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb8\x01\n$QueryIncentivizationProgramsResponse\x12S\n\x18incentivization_programs\x18\x01 \x03(\x0b\x32\x31.nibiru.incentivization.v1.IncentivizationProgram\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse2\x8f\x03\n\x03Msg\x12\xc6\x01\n\x1c\x43reateIncentivizationProgram\x12:.nibiru.incentivization.v1.MsgCreateIncentivizationProgram\x1a\x42.nibiru.incentivization.v1.MsgCreateIncentivizationProgramResponse\"&\x82\xd3\xe4\x93\x02 \"\x1e/nibiru/incentivization/create\x12\xbe\x01\n\x1a\x46undIncentivizationProgram\x12\x38.nibiru.incentivization.v1.MsgFundIncentivizationProgram\x1a@.nibiru.incentivization.v1.MsgFundIncentivizationProgramResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/nibiru/incentivization/fund2\xb7\x03\n\x05Query\x12\xd3\x01\n\x16IncentivizationProgram\x12=.nibiru.incentivization.v1.QueryIncentivizationProgramRequest\x1a>.nibiru.incentivization.v1.QueryIncentivizationProgramResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/nibiru/incentivization/v1/incentivization_program\x12\xd7\x01\n\x17IncentivizationPrograms\x12>.nibiru.incentivization.v1.QueryIncentivizationProgramsRequest\x1a?.nibiru.incentivization.v1.QueryIncentivizationProgramsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/nibiru/incentivization/v1/incentivization_programsB7Z5github.com/NibiruChain/nibiru/x/incentivization/typesb\x06proto3')



_MSGCREATEINCENTIVIZATIONPROGRAM = DESCRIPTOR.message_types_by_name['MsgCreateIncentivizationProgram']
_MSGCREATEINCENTIVIZATIONPROGRAMRESPONSE = DESCRIPTOR.message_types_by_name['MsgCreateIncentivizationProgramResponse']
_MSGFUNDINCENTIVIZATIONPROGRAM = DESCRIPTOR.message_types_by_name['MsgFundIncentivizationProgram']
_MSGFUNDINCENTIVIZATIONPROGRAMRESPONSE = DESCRIPTOR.message_types_by_name['MsgFundIncentivizationProgramResponse']
_INCENTIVIZATIONPROGRAM = DESCRIPTOR.message_types_by_name['IncentivizationProgram']
_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
_QUERYINCENTIVIZATIONPROGRAMREQUEST = DESCRIPTOR.message_types_by_name['QueryIncentivizationProgramRequest']
_QUERYINCENTIVIZATIONPROGRAMRESPONSE = DESCRIPTOR.message_types_by_name['QueryIncentivizationProgramResponse']
_QUERYINCENTIVIZATIONPROGRAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryIncentivizationProgramsRequest']
_QUERYINCENTIVIZATIONPROGRAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryIncentivizationProgramsResponse']
MsgCreateIncentivizationProgram = _reflection.GeneratedProtocolMessageType('MsgCreateIncentivizationProgram', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEINCENTIVIZATIONPROGRAM,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.MsgCreateIncentivizationProgram)
  })
_sym_db.RegisterMessage(MsgCreateIncentivizationProgram)

MsgCreateIncentivizationProgramResponse = _reflection.GeneratedProtocolMessageType('MsgCreateIncentivizationProgramResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEINCENTIVIZATIONPROGRAMRESPONSE,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.MsgCreateIncentivizationProgramResponse)
  })
_sym_db.RegisterMessage(MsgCreateIncentivizationProgramResponse)

MsgFundIncentivizationProgram = _reflection.GeneratedProtocolMessageType('MsgFundIncentivizationProgram', (_message.Message,), {
  'DESCRIPTOR' : _MSGFUNDINCENTIVIZATIONPROGRAM,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.MsgFundIncentivizationProgram)
  })
_sym_db.RegisterMessage(MsgFundIncentivizationProgram)

MsgFundIncentivizationProgramResponse = _reflection.GeneratedProtocolMessageType('MsgFundIncentivizationProgramResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGFUNDINCENTIVIZATIONPROGRAMRESPONSE,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.MsgFundIncentivizationProgramResponse)
  })
_sym_db.RegisterMessage(MsgFundIncentivizationProgramResponse)

IncentivizationProgram = _reflection.GeneratedProtocolMessageType('IncentivizationProgram', (_message.Message,), {
  'DESCRIPTOR' : _INCENTIVIZATIONPROGRAM,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.IncentivizationProgram)
  })
_sym_db.RegisterMessage(IncentivizationProgram)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

QueryIncentivizationProgramRequest = _reflection.GeneratedProtocolMessageType('QueryIncentivizationProgramRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINCENTIVIZATIONPROGRAMREQUEST,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.QueryIncentivizationProgramRequest)
  })
_sym_db.RegisterMessage(QueryIncentivizationProgramRequest)

QueryIncentivizationProgramResponse = _reflection.GeneratedProtocolMessageType('QueryIncentivizationProgramResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINCENTIVIZATIONPROGRAMRESPONSE,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.QueryIncentivizationProgramResponse)
  })
_sym_db.RegisterMessage(QueryIncentivizationProgramResponse)

QueryIncentivizationProgramsRequest = _reflection.GeneratedProtocolMessageType('QueryIncentivizationProgramsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINCENTIVIZATIONPROGRAMSREQUEST,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.QueryIncentivizationProgramsRequest)
  })
_sym_db.RegisterMessage(QueryIncentivizationProgramsRequest)

QueryIncentivizationProgramsResponse = _reflection.GeneratedProtocolMessageType('QueryIncentivizationProgramsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYINCENTIVIZATIONPROGRAMSRESPONSE,
  '__module__' : 'incentivization.v1.incentivization_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.incentivization.v1.QueryIncentivizationProgramsResponse)
  })
_sym_db.RegisterMessage(QueryIncentivizationProgramsResponse)

_MSG = DESCRIPTOR.services_by_name['Msg']
_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/NibiruChain/nibiru/x/incentivization/types'
  _MSGCREATEINCENTIVIZATIONPROGRAM.fields_by_name['min_lockup_duration']._options = None
  _MSGCREATEINCENTIVIZATIONPROGRAM.fields_by_name['min_lockup_duration']._serialized_options = b'\230\337\037\001'
  _MSGCREATEINCENTIVIZATIONPROGRAM.fields_by_name['start_time']._options = None
  _MSGCREATEINCENTIVIZATIONPROGRAM.fields_by_name['start_time']._serialized_options = b'\220\337\037\001'
  _MSGCREATEINCENTIVIZATIONPROGRAM.fields_by_name['initial_funds']._options = None
  _MSGCREATEINCENTIVIZATIONPROGRAM.fields_by_name['initial_funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _MSGFUNDINCENTIVIZATIONPROGRAM.fields_by_name['funds']._options = None
  _MSGFUNDINCENTIVIZATIONPROGRAM.fields_by_name['funds']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _INCENTIVIZATIONPROGRAM.fields_by_name['min_lockup_duration']._options = None
  _INCENTIVIZATIONPROGRAM.fields_by_name['min_lockup_duration']._serialized_options = b'\230\337\037\001\310\336\037\000'
  _INCENTIVIZATIONPROGRAM.fields_by_name['start_time']._options = None
  _INCENTIVIZATIONPROGRAM.fields_by_name['start_time']._serialized_options = b'\220\337\037\001\310\336\037\000'
  _MSG.methods_by_name['CreateIncentivizationProgram']._options = None
  _MSG.methods_by_name['CreateIncentivizationProgram']._serialized_options = b'\202\323\344\223\002 \"\036/nibiru/incentivization/create'
  _MSG.methods_by_name['FundIncentivizationProgram']._options = None
  _MSG.methods_by_name['FundIncentivizationProgram']._serialized_options = b'\202\323\344\223\002\036\"\034/nibiru/incentivization/fund'
  _QUERY.methods_by_name['IncentivizationProgram']._options = None
  _QUERY.methods_by_name['IncentivizationProgram']._serialized_options = b'\202\323\344\223\0024\0222/nibiru/incentivization/v1/incentivization_program'
  _QUERY.methods_by_name['IncentivizationPrograms']._options = None
  _QUERY.methods_by_name['IncentivizationPrograms']._serialized_options = b'\202\323\344\223\0025\0223/nibiru/incentivization/v1/incentivization_programs'
  _MSGCREATEINCENTIVIZATIONPROGRAM._serialized_start=265
  _MSGCREATEINCENTIVIZATIONPROGRAM._serialized_end=564
  _MSGCREATEINCENTIVIZATIONPROGRAMRESPONSE._serialized_start=566
  _MSGCREATEINCENTIVIZATIONPROGRAMRESPONSE._serialized_end=627
  _MSGFUNDINCENTIVIZATIONPROGRAM._serialized_start=630
  _MSGFUNDINCENTIVIZATIONPROGRAM._serialized_end=781
  _MSGFUNDINCENTIVIZATIONPROGRAMRESPONSE._serialized_start=783
  _MSGFUNDINCENTIVIZATIONPROGRAMRESPONSE._serialized_end=822
  _INCENTIVIZATIONPROGRAM._serialized_start=825
  _INCENTIVIZATIONPROGRAM._serialized_end=1053
  _GENESISSTATE._serialized_start=1055
  _GENESISSTATE._serialized_end=1154
  _QUERYINCENTIVIZATIONPROGRAMREQUEST._serialized_start=1156
  _QUERYINCENTIVIZATIONPROGRAMREQUEST._serialized_end=1204
  _QUERYINCENTIVIZATIONPROGRAMRESPONSE._serialized_start=1206
  _QUERYINCENTIVIZATIONPROGRAMRESPONSE._serialized_end=1327
  _QUERYINCENTIVIZATIONPROGRAMSREQUEST._serialized_start=1329
  _QUERYINCENTIVIZATIONPROGRAMSREQUEST._serialized_end=1426
  _QUERYINCENTIVIZATIONPROGRAMSRESPONSE._serialized_start=1429
  _QUERYINCENTIVIZATIONPROGRAMSRESPONSE._serialized_end=1613
  _MSG._serialized_start=1616
  _MSG._serialized_end=2015
  _QUERY._serialized_start=2018
  _QUERY._serialized_end=2457
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/capability/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.capability.v1beta1 import capability_pb2 as cosmos_dot_capability_dot_v1beta1_dot_capability__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'cosmos/capability/v1beta1/genesis.proto\x12\x19\x63osmos.capability.v1beta1\x1a\x14gogoproto/gogo.proto\x1a*cosmos/capability/v1beta1/capability.proto\"~\n\rGenesisOwners\x12\r\n\x05index\x18\x01 \x01(\x04\x12^\n\x0cindex_owners\x18\x02 \x01(\x0b\x32+.cosmos.capability.v1beta1.CapabilityOwnersB\x1b\xc8\xde\x1f\x00\xf2\xde\x1f\x13yaml:\"index_owners\"\"]\n\x0cGenesisState\x12\r\n\x05index\x18\x01 \x01(\x04\x12>\n\x06owners\x18\x02 \x03(\x0b\x32(.cosmos.capability.v1beta1.GenesisOwnersB\x04\xc8\xde\x1f\x00\x42\x31Z/github.com/cosmos/cosmos-sdk/x/capability/typesb\x06proto3')



_GENESISOWNERS = DESCRIPTOR.message_types_by_name['GenesisOwners']
_GENESISSTATE = DESCRIPTOR.message_types_by_name['GenesisState']
GenesisOwners = _reflection.GeneratedProtocolMessageType('GenesisOwners', (_message.Message,), {
  'DESCRIPTOR' : _GENESISOWNERS,
  '__module__' : 'cosmos.capability.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.capability.v1beta1.GenesisOwners)
  })
_sym_db.RegisterMessage(GenesisOwners)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'cosmos.capability.v1beta1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.capability.v1beta1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/cosmos/cosmos-sdk/x/capability/types'
  _GENESISOWNERS.fields_by_name['index_owners']._options = None
  _GENESISOWNERS.fields_by_name['index_owners']._serialized_options = b'\310\336\037\000\362\336\037\023yaml:\"index_owners\"'
  _GENESISSTATE.fields_by_name['owners']._options = None
  _GENESISSTATE.fields_by_name['owners']._serialized_options = b'\310\336\037\000'
  _GENESISOWNERS._serialized_start=136
  _GENESISOWNERS._serialized_end=262
  _GENESISSTATE._serialized_start=264
  _GENESISSTATE._serialized_end=357
# @@protoc_insertion_point(module_scope)



from typing import List

from nibiru.common import PoolAsset
from nibiru.composers.dex import Dex as DexComposer
from nibiru.proto.cosmos.base.v1beta1 import coin_pb2 as coin_pb

from .common import Tx


class Dex(Tx):
    def create_pool(self, creator: str, swap_fee: str, exit_fee: str, assets: List[PoolAsset], **kwargs):
        msg = DexComposer.create_pool(creator=creator, swap_fee=swap_fee, exit_fee=exit_fee, assets=assets)
        return super().execute_msg(msg, **kwargs)

    def join_pool(self, sender: str, pool_id: int, tokens: List[coin_pb.Coin], **kwargs):
        msg = DexComposer.join_pool(sender=sender, pool_id=pool_id, tokens=tokens)
        return super().execute_msg(msg, **kwargs)

    def exit_pool(self, sender: str, pool_id: int, pool_shares: coin_pb.Coin, **kwargs):
        msg = DexComposer.exit_pool(sender=sender, pool_id=pool_id, pool_shares=pool_shares)
        return super().execute_msg(msg, **kwargs)

    def swap_assets(self, sender: str, pool_id: int, token_in: coin_pb.Coin, token_out_denom, **kwargs):
        msg = DexComposer.swap_assets(
            sender=sender,
            pool_id=pool_id,
            token_in=token_in,
            token_out_denom=token_out_denom,
        )
        return super().execute_msg(msg, **kwargs)



from grpc import Channel

from nibiru.common import Direction
from nibiru.proto.vpool.v1 import query_pb2 as vpool_type
from nibiru.proto.vpool.v1 import query_pb2_grpc as vpool_query
from nibiru.proto.vpool.v1.vpool_pb2 import Direction as pbDirection

from .util import deserialize


class VPool:
    """
    VPool allows to query the endpoints made available by the Nibiru Chain's VPOOL module.
    """

    def __init__(self, channel: Channel):
        self.api = vpool_query.QueryStub(channel)

    def reserve_assets(self, pair: str):
        req = vpool_type.QueryReserveAssetsRequest(pair=pair)
        return deserialize(self.api.ReserveAssets(req))

    def all_pools(self):
        req = vpool_type.QueryAllPoolsRequest()
        return deserialize(self.api.AllPools(req))

    def base_asset_price(self, pair: str, direction: Direction, base_asset_amount: str):
        dir_pb = pbDirection.DIRECTION_UNSPECIFIED
        if direction == Direction.ADD:
            dir_pb = pbDirection.ADD_TO_POOL
        elif direction == Direction.REMOVE:
            dir_pb = pbDirection.REMOVE_FROM_POOL

        req = vpool_type.QueryBaseAssetPriceRequest(pair=pair, direction=dir_pb, base_asset_amount=base_asset_amount)
        return deserialize(self.api.BaseAssetPrice(req))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/libs/bits/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/libs/bits/types.proto\x12\x14tendermint.libs.bits\"\'\n\x08\x42itArray\x12\x0c\n\x04\x62its\x18\x01 \x01(\x03\x12\r\n\x05\x65lems\x18\x02 \x03(\x04\x42=Z;github.com/tendermint/tendermint/proto/tendermint/libs/bitsb\x06proto3')



_BITARRAY = DESCRIPTOR.message_types_by_name['BitArray']
BitArray = _reflection.GeneratedProtocolMessageType('BitArray', (_message.Message,), {
  'DESCRIPTOR' : _BITARRAY,
  '__module__' : 'tendermint.libs.bits.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.libs.bits.BitArray)
  })
_sym_db.RegisterMessage(BitArray)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z;github.com/tendermint/tendermint/proto/tendermint/libs/bits'
  _BITARRAY._serialized_start=58
  _BITARRAY._serialized_end=97
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/tendermint/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from tendermint.types import block_pb2 as tendermint_dot_types_dot_block__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*cosmos/base/tendermint/v1beta1/query.proto\x12\x1e\x63osmos.base.tendermint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1atendermint/p2p/types.proto\x1a\x1ctendermint/types/block.proto\x1a\x1ctendermint/types/types.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\"l\n\x1eGetValidatorSetByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb3\x01\n\x1fGetValidatorSetByHeightResponse\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x03\x12=\n\nvalidators\x18\x02 \x03(\x0b\x32).cosmos.base.tendermint.v1beta1.Validator\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"Z\n\x1cGetLatestValidatorSetRequest\x12:\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xb1\x01\n\x1dGetLatestValidatorSetResponse\x12\x14\n\x0c\x62lock_height\x18\x01 \x01(\x03\x12=\n\nvalidators\x18\x02 \x03(\x0b\x32).cosmos.base.tendermint.v1beta1.Validator\x12;\n\npagination\x18\x03 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"t\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12%\n\x07pub_key\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x14\n\x0cvoting_power\x18\x03 \x01(\x03\x12\x19\n\x11proposer_priority\x18\x04 \x01(\x03\")\n\x17GetBlockByHeightRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"o\n\x18GetBlockByHeightResponse\x12+\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tendermint.types.Block\"\x17\n\x15GetLatestBlockRequest\"m\n\x16GetLatestBlockResponse\x12+\n\x08\x62lock_id\x18\x01 \x01(\x0b\x32\x19.tendermint.types.BlockID\x12&\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x17.tendermint.types.Block\"\x13\n\x11GetSyncingRequest\"%\n\x12GetSyncingResponse\x12\x0f\n\x07syncing\x18\x01 \x01(\x08\"\x14\n\x12GetNodeInfoRequest\"\x9b\x01\n\x13GetNodeInfoResponse\x12:\n\x11\x64\x65\x66\x61ult_node_info\x18\x01 \x01(\x0b\x32\x1f.tendermint.p2p.DefaultNodeInfo\x12H\n\x13\x61pplication_version\x18\x02 \x01(\x0b\x32+.cosmos.base.tendermint.v1beta1.VersionInfo\"\xd2\x01\n\x0bVersionInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x12\n\ngit_commit\x18\x04 \x01(\t\x12\x12\n\nbuild_tags\x18\x05 \x01(\t\x12\x12\n\ngo_version\x18\x06 \x01(\t\x12:\n\nbuild_deps\x18\x07 \x03(\x0b\x32&.cosmos.base.tendermint.v1beta1.Module\x12\x1a\n\x12\x63osmos_sdk_version\x18\x08 \x01(\t\"4\n\x06Module\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0b\n\x03sum\x18\x03 \x01(\t2\x88\t\n\x07Service\x12\xa9\x01\n\x0bGetNodeInfo\x12\x32.cosmos.base.tendermint.v1beta1.GetNodeInfoRequest\x1a\x33.cosmos.base.tendermint.v1beta1.GetNodeInfoResponse\"1\x82\xd3\xe4\x93\x02+\x12)/cosmos/base/tendermint/v1beta1/node_info\x12\xa4\x01\n\nGetSyncing\x12\x31.cosmos.base.tendermint.v1beta1.GetSyncingRequest\x1a\x32.cosmos.base.tendermint.v1beta1.GetSyncingResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/base/tendermint/v1beta1/syncing\x12\xb6\x01\n\x0eGetLatestBlock\x12\x35.cosmos.base.tendermint.v1beta1.GetLatestBlockRequest\x1a\x36.cosmos.base.tendermint.v1beta1.GetLatestBlockResponse\"5\x82\xd3\xe4\x93\x02/\x12-/cosmos/base/tendermint/v1beta1/blocks/latest\x12\xbe\x01\n\x10GetBlockByHeight\x12\x37.cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest\x1a\x38.cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//cosmos/base/tendermint/v1beta1/blocks/{height}\x12\xd2\x01\n\x15GetLatestValidatorSet\x12<.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest\x1a=.cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/base/tendermint/v1beta1/validatorsets/latest\x12\xda\x01\n\x17GetValidatorSetByHeight\x12>.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest\x1a?.cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/cosmos/base/tendermint/v1beta1/validatorsets/{height}B4Z2github.com/cosmos/cosmos-sdk/client/grpc/tmserviceb\x06proto3')



_GETVALIDATORSETBYHEIGHTREQUEST = DESCRIPTOR.message_types_by_name['GetValidatorSetByHeightRequest']
_GETVALIDATORSETBYHEIGHTRESPONSE = DESCRIPTOR.message_types_by_name['GetValidatorSetByHeightResponse']
_GETLATESTVALIDATORSETREQUEST = DESCRIPTOR.message_types_by_name['GetLatestValidatorSetRequest']
_GETLATESTVALIDATORSETRESPONSE = DESCRIPTOR.message_types_by_name['GetLatestValidatorSetResponse']
_VALIDATOR = DESCRIPTOR.message_types_by_name['Validator']
_GETBLOCKBYHEIGHTREQUEST = DESCRIPTOR.message_types_by_name['GetBlockByHeightRequest']
_GETBLOCKBYHEIGHTRESPONSE = DESCRIPTOR.message_types_by_name['GetBlockByHeightResponse']
_GETLATESTBLOCKREQUEST = DESCRIPTOR.message_types_by_name['GetLatestBlockRequest']
_GETLATESTBLOCKRESPONSE = DESCRIPTOR.message_types_by_name['GetLatestBlockResponse']
_GETSYNCINGREQUEST = DESCRIPTOR.message_types_by_name['GetSyncingRequest']
_GETSYNCINGRESPONSE = DESCRIPTOR.message_types_by_name['GetSyncingResponse']
_GETNODEINFOREQUEST = DESCRIPTOR.message_types_by_name['GetNodeInfoRequest']
_GETNODEINFORESPONSE = DESCRIPTOR.message_types_by_name['GetNodeInfoResponse']
_VERSIONINFO = DESCRIPTOR.message_types_by_name['VersionInfo']
_MODULE = DESCRIPTOR.message_types_by_name['Module']
GetValidatorSetByHeightRequest = _reflection.GeneratedProtocolMessageType('GetValidatorSetByHeightRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVALIDATORSETBYHEIGHTREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightRequest)
  })
_sym_db.RegisterMessage(GetValidatorSetByHeightRequest)

GetValidatorSetByHeightResponse = _reflection.GeneratedProtocolMessageType('GetValidatorSetByHeightResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVALIDATORSETBYHEIGHTRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetValidatorSetByHeightResponse)
  })
_sym_db.RegisterMessage(GetValidatorSetByHeightResponse)

GetLatestValidatorSetRequest = _reflection.GeneratedProtocolMessageType('GetLatestValidatorSetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTVALIDATORSETREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetLatestValidatorSetRequest)
  })
_sym_db.RegisterMessage(GetLatestValidatorSetRequest)

GetLatestValidatorSetResponse = _reflection.GeneratedProtocolMessageType('GetLatestValidatorSetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTVALIDATORSETRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetLatestValidatorSetResponse)
  })
_sym_db.RegisterMessage(GetLatestValidatorSetResponse)

Validator = _reflection.GeneratedProtocolMessageType('Validator', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATOR,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.Validator)
  })
_sym_db.RegisterMessage(Validator)

GetBlockByHeightRequest = _reflection.GeneratedProtocolMessageType('GetBlockByHeightRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKBYHEIGHTREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetBlockByHeightRequest)
  })
_sym_db.RegisterMessage(GetBlockByHeightRequest)

GetBlockByHeightResponse = _reflection.GeneratedProtocolMessageType('GetBlockByHeightResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETBLOCKBYHEIGHTRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetBlockByHeightResponse)
  })
_sym_db.RegisterMessage(GetBlockByHeightResponse)

GetLatestBlockRequest = _reflection.GeneratedProtocolMessageType('GetLatestBlockRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTBLOCKREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetLatestBlockRequest)
  })
_sym_db.RegisterMessage(GetLatestBlockRequest)

GetLatestBlockResponse = _reflection.GeneratedProtocolMessageType('GetLatestBlockResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLATESTBLOCKRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetLatestBlockResponse)
  })
_sym_db.RegisterMessage(GetLatestBlockResponse)

GetSyncingRequest = _reflection.GeneratedProtocolMessageType('GetSyncingRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSYNCINGREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetSyncingRequest)
  })
_sym_db.RegisterMessage(GetSyncingRequest)

GetSyncingResponse = _reflection.GeneratedProtocolMessageType('GetSyncingResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSYNCINGRESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetSyncingResponse)
  })
_sym_db.RegisterMessage(GetSyncingResponse)

GetNodeInfoRequest = _reflection.GeneratedProtocolMessageType('GetNodeInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEINFOREQUEST,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetNodeInfoRequest)
  })
_sym_db.RegisterMessage(GetNodeInfoRequest)

GetNodeInfoResponse = _reflection.GeneratedProtocolMessageType('GetNodeInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNODEINFORESPONSE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.GetNodeInfoResponse)
  })
_sym_db.RegisterMessage(GetNodeInfoResponse)

VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINFO,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.VersionInfo)
  })
_sym_db.RegisterMessage(VersionInfo)

Module = _reflection.GeneratedProtocolMessageType('Module', (_message.Message,), {
  'DESCRIPTOR' : _MODULE,
  '__module__' : 'cosmos.base.tendermint.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.tendermint.v1beta1.Module)
  })
_sym_db.RegisterMessage(Module)

_SERVICE = DESCRIPTOR.services_by_name['Service']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/cosmos/cosmos-sdk/client/grpc/tmservice'
  _SERVICE.methods_by_name['GetNodeInfo']._options = None
  _SERVICE.methods_by_name['GetNodeInfo']._serialized_options = b'\202\323\344\223\002+\022)/cosmos/base/tendermint/v1beta1/node_info'
  _SERVICE.methods_by_name['GetSyncing']._options = None
  _SERVICE.methods_by_name['GetSyncing']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/base/tendermint/v1beta1/syncing'
  _SERVICE.methods_by_name['GetLatestBlock']._options = None
  _SERVICE.methods_by_name['GetLatestBlock']._serialized_options = b'\202\323\344\223\002/\022-/cosmos/base/tendermint/v1beta1/blocks/latest'
  _SERVICE.methods_by_name['GetBlockByHeight']._options = None
  _SERVICE.methods_by_name['GetBlockByHeight']._serialized_options = b'\202\323\344\223\0021\022//cosmos/base/tendermint/v1beta1/blocks/{height}'
  _SERVICE.methods_by_name['GetLatestValidatorSet']._options = None
  _SERVICE.methods_by_name['GetLatestValidatorSet']._serialized_options = b'\202\323\344\223\0026\0224/cosmos/base/tendermint/v1beta1/validatorsets/latest'
  _SERVICE.methods_by_name['GetValidatorSetByHeight']._options = None
  _SERVICE.methods_by_name['GetValidatorSetByHeight']._serialized_options = b'\202\323\344\223\0028\0226/cosmos/base/tendermint/v1beta1/validatorsets/{height}'
  _GETVALIDATORSETBYHEIGHTREQUEST._serialized_start=289
  _GETVALIDATORSETBYHEIGHTREQUEST._serialized_end=397
  _GETVALIDATORSETBYHEIGHTRESPONSE._serialized_start=400
  _GETVALIDATORSETBYHEIGHTRESPONSE._serialized_end=579
  _GETLATESTVALIDATORSETREQUEST._serialized_start=581
  _GETLATESTVALIDATORSETREQUEST._serialized_end=671
  _GETLATESTVALIDATORSETRESPONSE._serialized_start=674
  _GETLATESTVALIDATORSETRESPONSE._serialized_end=851
  _VALIDATOR._serialized_start=853
  _VALIDATOR._serialized_end=969
  _GETBLOCKBYHEIGHTREQUEST._serialized_start=971
  _GETBLOCKBYHEIGHTREQUEST._serialized_end=1012
  _GETBLOCKBYHEIGHTRESPONSE._serialized_start=1014
  _GETBLOCKBYHEIGHTRESPONSE._serialized_end=1125
  _GETLATESTBLOCKREQUEST._serialized_start=1127
  _GETLATESTBLOCKREQUEST._serialized_end=1150
  _GETLATESTBLOCKRESPONSE._serialized_start=1152
  _GETLATESTBLOCKRESPONSE._serialized_end=1261
  _GETSYNCINGREQUEST._serialized_start=1263
  _GETSYNCINGREQUEST._serialized_end=1282
  _GETSYNCINGRESPONSE._serialized_start=1284
  _GETSYNCINGRESPONSE._serialized_end=1321
  _GETNODEINFOREQUEST._serialized_start=1323
  _GETNODEINFOREQUEST._serialized_end=1343
  _GETNODEINFORESPONSE._serialized_start=1346
  _GETNODEINFORESPONSE._serialized_end=1501
  _VERSIONINFO._serialized_start=1504
  _VERSIONINFO._serialized_end=1714
  _MODULE._serialized_start=1716
  _MODULE._serialized_end=1768
  _SERVICE._serialized_start=1771
  _SERVICE._serialized_end=2931
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from epochs import query_pb2 as epochs_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.EpochInfos = channel.unary_unary(
                '/nibiru.epochs.v1beta1.Query/EpochInfos',
                request_serializer=epochs_dot_query__pb2.QueryEpochsInfoRequest.SerializeToString,
                response_deserializer=epochs_dot_query__pb2.QueryEpochsInfoResponse.FromString,
                )
        self.CurrentEpoch = channel.unary_unary(
                '/nibiru.epochs.v1beta1.Query/CurrentEpoch',
                request_serializer=epochs_dot_query__pb2.QueryCurrentEpochRequest.SerializeToString,
                response_deserializer=epochs_dot_query__pb2.QueryCurrentEpochResponse.FromString,
                )


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def EpochInfos(self, request, context):
        """EpochInfos provide running epochInfos
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CurrentEpoch(self, request, context):
        """CurrentEpoch provide current epoch of specified identifier
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'EpochInfos': grpc.unary_unary_rpc_method_handler(
                    servicer.EpochInfos,
                    request_deserializer=epochs_dot_query__pb2.QueryEpochsInfoRequest.FromString,
                    response_serializer=epochs_dot_query__pb2.QueryEpochsInfoResponse.SerializeToString,
            ),
            'CurrentEpoch': grpc.unary_unary_rpc_method_handler(
                    servicer.CurrentEpoch,
                    request_deserializer=epochs_dot_query__pb2.QueryCurrentEpochRequest.FromString,
                    response_serializer=epochs_dot_query__pb2.QueryCurrentEpochResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nibiru.epochs.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def EpochInfos(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.epochs.v1beta1.Query/EpochInfos',
            epochs_dot_query__pb2.QueryEpochsInfoRequest.SerializeToString,
            epochs_dot_query__pb2.QueryEpochsInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CurrentEpoch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nibiru.epochs.v1beta1.Query/CurrentEpoch',
            epochs_dot_query__pb2.QueryCurrentEpochRequest.SerializeToString,
            epochs_dot_query__pb2.QueryCurrentEpochResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
